var srv__config_8h =
[
    [ "isc::dhcp::SrvConfig", "d8/da2/classisc_1_1dhcp_1_1SrvConfig.html", "d8/da2/classisc_1_1dhcp_1_1SrvConfig" ],
    [ "ConstSrvConfigPtr", "d4/db8/srv__config_8h.html#a251e5e22500b5f7a5dd1f98f04c7ecdd", null ],
    [ "SrvConfigPtr", "d4/db8/srv__config_8h.html#a5d237061813dc08c438cc5f0c7883884", null ]
];